<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Lock-Nessie Auth Server</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="icon" href="{{ url_for('static', path='favicon.ico') }}">
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Inter', sans-serif;
        }
    </style>
</head>
<body class="bg-gray-50">
    <div class="min-h-screen">
        <!-- Header -->
        <header class="bg-white shadow-sm">
            <div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-4">
                <div class="flex justify-between items-center">
                    <div class="flex items-center">
                        <img src="{{ url_for('static', path='logo.png') }}" alt="Nessie Logo" class="h-8 w-auto">
                        <span class="ml-2 text-xl font-semibold text-gray-900">Lock-Nessie</span>
                    </div>
                    <a href="https://github.com/pirate-baby/lock-nessie" class="text-gray-600 hover:text-gray-900">
                        <svg class="h-6 w-6" fill="currentColor" viewBox="0 0 24 24">
                            <path fill-rule="evenodd" d="M12 2C6.477 2 2 6.484 2 12.017c0 4.425 2.865 8.18 6.839 9.504.5.092.682-.217.682-.483 0-.237-.008-.868-.013-1.703-2.782.605-3.369-1.343-3.369-1.343-.454-1.158-1.11-1.466-1.11-1.466-.908-.62.069-.608.069-.608 1.003.07 1.531 1.032 1.531 1.032.892 1.53 2.341 1.088 2.91.832.092-.647.35-1.088.636-1.338-2.22-.253-4.555-1.113-4.555-4.951 0-1.093.39-1.988 1.029-2.688-.103-.253-.446-1.272.098-2.65 0 0 .84-.27 2.75 1.026A9.564 9.564 0 0112 6.844c.85.004 1.705.115 2.504.337 1.909-1.296 2.747-1.027 2.747-1.027.546 1.379.202 2.398.1 2.651.64.7 1.028 1.595 1.028 2.688 0 3.848-2.339 4.695-4.566 4.943.359.309.678.92.678 1.855 0 1.338-.012 2.419-.012 2.747 0 .268.18.58.688.482A10.019 10.019 0 0022 12.017C22 6.484 17.522 2 12 2z" clip-rule="evenodd"/>
                        </svg>
                    </a>
                </div>
            </div>
        </header>

        <!-- Main Content -->
        <main class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
            <div class="bg-white shadow rounded-lg p-6">
                <div class="space-y-6">
                    {% if is_logged_in %}
                    <!-- User Info -->
                    <div class="border-b border-gray-200 pb-6">
                        <h2 class="text-2xl font-bold text-gray-900 mb-4">Welcome, {{ user }}!</h2>
                        <p class="text-gray-600">
                            You are currently logged in. Your session will expire in <span class="font-semibold">{{ time_until_expiry }}</span> (at {{ expires.strftime("%A, %B %d, %Y at %H:%M %Z") }}).
                        </p>
                    </div>

                    <!-- AWS Secret URI -->
                    {% if aws_secret_arn %}
                    <div class="border-b border-gray-200 pb-6">
                        <h3 class="text-lg font-semibold text-gray-900 mb-2">AWS Secret ARN</h3>
                        <p>You may need this value to set up your local client or Dremio connector.</p>
                        <div class="bg-gray-50 p-4 rounded-md">
                            <code class="text-sm text-gray-800 break-all">{{ aws_secret_arn }}</code>
                        </div>
                    </div>
                    {% endif %}

                    <!-- Quick Links -->
                    <div>
                        <div class="grid grid-cols-1 gap-4 sm:grid-cols-2">
                            <a href="/auth/logout" class="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md text-white bg-red-600 hover:bg-red-700">
                                Logout
                            </a>
                        </div>
                    </div>
                    {% else %}
                    <!-- Not Logged In -->
                    <div class="text-center py-12">
                        <h2 class="text-2xl font-bold text-gray-900 mb-4">Welcome to Lock-Nessie</h2>
                        <p class="text-gray-600 mb-8">
                            You are not currently logged in. Please log in to access your authentication information.
                        </p>
                        <a href="/auth/login" class="inline-flex items-center px-6 py-3 border border-transparent text-base font-medium rounded-md text-white bg-blue-600 hover:bg-blue-700">
                            Log In
                        </a>
                    </div>
                    {% endif %}
                </div>
            </div>
        </main>
    </div>
</body>
</html>
